@@ -32,7 +32,7 @@ var NAVTREE =
       [ "Installing the binaries on Windows", "install.html#install_bin_windows", null ]
     ] ],
     [ "Getting started", "starting.html", [
-      [ "Step 0: Check if doxygen supports your programming language", "starting.html#step0", null ],
+      [ "Step 0: Check if doxygen supports your programming/hardware description language", "starting.html#step0", null ],
       [ "Step 1: Creating a configuration file", "starting.html#step1", null ],
       [ "Step 2: Running doxygen", "starting.html#step2", [
         [ "HTML output", "starting.html#html_out", null ],
@@ -79,7 +79,8 @@ var NAVTREE =
         [ "Table of Contents", "markdown.html#md_toc", null ],
         [ "Tables", "markdown.html#md_tables", null ],
         [ "Fenced Code Blocks", "markdown.html#md_fenced", null ],
-        [ "Header Id Attributes", "markdown.html#md_header_id", null ]
+        [ "Header Id Attributes", "markdown.html#md_header_id", null ],
+        [ "Image Attributes", "markdown.html#md_image_attributes", null ]
       ] ],
       [ "Doxygen specifics", "markdown.html#markdown_dox", [
         [ "Including Markdown files as pages", "markdown.html#md_page_header", null ],
@@ -91,11 +92,11 @@ var NAVTREE =
         [ "Use of asterisks", "markdown.html#mddox_stars", null ],
         [ "Limits on markup scope", "markdown.html#mddox_limits", null ]
       ] ],
-      [ "Debugging of problems", "markdown.html#markdown_debug", null ]
+      [ "Debugging problems", "markdown.html#markdown_debug", null ]
     ] ],
     [ "Lists", "lists.html", null ],
     [ "Grouping", "grouping.html", [
-      [ "Modules", "grouping.html#modules", null ],
+      [ "Topics", "grouping.html#topics", null ],
       [ "Member Groups", "grouping.html#memgroup", null ],
       [ "Subpaging", "grouping.html#subpaging", null ]
     ] ],
@@ -112,7 +113,21 @@ var NAVTREE =
       [ "typedefs", "autolink.html#resolving", null ]
     ] ],
     [ "Output Formats", "output.html", null ],
-    [ "Searching", "searching.html", "searching" ],
+    [ "Searching", "searching.html", [
+      [ "External Indexing and Searching", "extsearch.html", [
+        [ "Introduction", "extsearch.html#extsearch_intro", null ],
+        [ "Configuring", "extsearch.html#extsearch_config", [
+          [ "Single project index", "extsearch.html#extsearch_single", null ],
+          [ "Multi project index", "extsearch.html#extsearch_multi", null ]
+        ] ],
+        [ "Updating the index", "extsearch.html#extsearch_update", null ],
+        [ "Programming interface", "extsearch.html#extsearch_api", [
+          [ "Indexer input format", "extsearch.html#extsearch_api_index", null ],
+          [ "Search URL format", "extsearch.html#extsearch_api_search_in", null ],
+          [ "Search results format", "extsearch.html#extsearch_api_search_out", null ]
+        ] ]
+      ] ]
+    ] ],
     [ "Customizing the output", "customize.html", [
       [ "Minor Tweaks", "customize.html#minor_tweaks", [
         [ "Overall Color", "customize.html#minor_tweaks_colors", null ],
@@ -149,7 +164,8 @@ var NAVTREE =
       [ "I have problems getting the search engine to work with PHP5 and/or windows", "faq.html#faq_search", null ],
       [ "Can I configure doxygen from the command line?", "faq.html#faq_cmdline", null ],
       [ "How did doxygen get its name?", "faq.html#faq_name", null ],
-      [ "What was the reason to develop doxygen?", "faq.html#faq_why", null ]
+      [ "What was the reason to develop doxygen?", "faq.html#faq_why", null ],
+      [ "How to prevent interleaved output", "faq.html#faq_bin", null ]
     ] ],
     [ "Troubleshooting", "trouble.html", [
       [ "Known Problems", "trouble.html#knowproblems", null ],
@@ -194,7 +210,7 @@ var NAVTREE =
       [ "Configuration options related to the Perl module output", "config.html#config_perlmod", null ],
       [ "Configuration options related to the preprocessor", "config.html#config_preprocessor", null ],
       [ "Configuration options related to external references", "config.html#config_external", null ],
-      [ "Configuration options related to the dot tool", "config.html#config_dot", null ],
+      [ "Configuration options related to diagram generator tools", "config.html#config_dot", null ],
       [ "Examples", "config.html#config_examples", null ]
     ] ],
     [ "Special Commands", "commands.html", [
@@ -208,8 +224,20 @@ var NAVTREE =
       [ "\\hiderefby", "commands.html#cmdhiderefby", null ],
       [ "\\showrefs", "commands.html#cmdshowrefs", null ],
       [ "\\hiderefs", "commands.html#cmdhiderefs", null ],
+      [ "\\includegraph", "commands.html#cmdincludegraph", null ],
+      [ "\\hideincludegraph", "commands.html#cmdhideincludegraph", null ],
+      [ "\\includedbygraph", "commands.html#cmdincludedbygraph", null ],
+      [ "\\hideincludedbygraph", "commands.html#cmdhideincludedbygraph", null ],
+      [ "\\directorygraph", "commands.html#cmddirectorygraph", null ],
+      [ "\\hidedirectorygraph", "commands.html#cmdhidedirectorygraph", null ],
+      [ "\\collaborationgraph", "commands.html#cmdcollaborationgraph", null ],
+      [ "\\hidecollaborationgraph", "commands.html#cmdhidecollaborationgraph", null ],
+      [ "\\groupgraph", "commands.html#cmdgroupgraph", null ],
+      [ "\\hidegroupgraph", "commands.html#cmdhidegroupgraph", null ],
+      [ "\\qualifier <label> | \"(text)\"", "commands.html#cmdqualifier", null ],
       [ "\\category <name> [<header-file>] [<header-name>]", "commands.html#cmdcategory", null ],
       [ "\\class <name> [<header-file>] [<header-name>]", "commands.html#cmdclass", null ],
+      [ "\\concept <name>", "commands.html#cmdconcept", null ],
       [ "\\def <name>", "commands.html#cmddef", null ],
       [ "\\defgroup <name> (group title)", "commands.html#cmddefgroup", null ],
       [ "\\dir [<path fragment>]", "commands.html#cmddir", null ],
@@ -218,16 +246,19 @@ var NAVTREE =
       [ "\\endinternal", "commands.html#cmdendinternal", null ],
       [ "\\extends <name>", "commands.html#cmdextends", null ],
       [ "\\file [<name>]", "commands.html#cmdfile", null ],
+      [ "\\fileinfo['{'option'}']", "commands.html#cmdfileinfo", null ],
+      [ "\\lineinfo", "commands.html#cmdlineinfo", null ],
       [ "\\fn (function declaration)", "commands.html#cmdfn", null ],
       [ "\\headerfile <header-file> [<header-name>]", "commands.html#cmdheaderfile", null ],
       [ "\\hideinitializer", "commands.html#cmdhideinitializer", null ],
       [ "\\idlexcept <name>", "commands.html#cmdidlexcept", null ],
       [ "\\implements <name>", "commands.html#cmdimplements", null ],
-      [ "\\ingroup (<groupname> [<groupname> <groupname>])", "commands.html#cmdingroup", null ],
+      [ "\\ingroup (<groupname> [<groupname>]*)", "commands.html#cmdingroup", null ],
       [ "\\interface <name> [<header-file>] [<header-name>]", "commands.html#cmdinterface", null ],
       [ "\\internal", "commands.html#cmdinternal", null ],
       [ "\\mainpage [(title)]", "commands.html#cmdmainpage", null ],
       [ "\\memberof <name>", "commands.html#cmdmemberof", null ],
+      [ "\\module <name>", "commands.html#cmdmodule", null ],
       [ "\\name [(header)]", "commands.html#cmdname", null ],
       [ "\\namespace <name>", "commands.html#cmdnamespace", null ],
       [ "\\nosubgrouping", "commands.html#cmdnosubgrouping", null ],
@@ -263,9 +294,11 @@ var NAVTREE =
       [ "\\cond [(section-label)]", "commands.html#cmdcond", null ],
       [ "\\copyright { copyright description }", "commands.html#cmdcopyright", null ],
       [ "\\date { date description }", "commands.html#cmddate", null ],
+      [ "\\showdate \"<format>\" [ <date_time> ]", "commands.html#cmdshowdate", null ],
       [ "\\deprecated { description }", "commands.html#cmddeprecated", null ],
       [ "\\details { detailed description }", "commands.html#cmddetails", null ],
       [ "\\noop ( text to be ignored )", "commands.html#cmdnoop", null ],
+      [ "\\raisewarning ( text to be shown as warning )", "commands.html#cmdraisewarning", null ],
       [ "\\else", "commands.html#cmdelse", null ],
       [ "\\elseif (section-label)", "commands.html#cmdelseif", null ],
       [ "\\endcond", "commands.html#cmdendcond", null ],
@@ -298,7 +331,7 @@ var NAVTREE =
       [ "\\todo { paragraph describing what is to be done }", "commands.html#cmdtodo", null ],
       [ "\\version { version number }", "commands.html#cmdversion", null ],
       [ "\\warning { warning message }", "commands.html#cmdwarning", null ],
-      [ "\\xrefitem <key> \"(heading)\" \"(list title)\" { text }", "commands.html#cmdxrefitem", null ],
+      [ "\\xrefitem <key> \"heading\" \"list title\" { text }", "commands.html#cmdxrefitem", null ],
       [ "\\addindex (text)", "commands.html#cmdaddindex", null ],
       [ "\\anchor <word>", "commands.html#cmdanchor", null ],
       [ "\\cite <label>", "commands.html#cmdcite", null ],
@@ -344,10 +377,11 @@ var NAVTREE =
       [ "\\dot [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddot", null ],
       [ "\\emoji \"name\"", "commands.html#cmdemoji", null ],
       [ "\\msc [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmsc", null ],
-      [ "\\startuml [{file}] [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdstartuml", null ],
+      [ "\\startuml ['{'option[,option]'}'] [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdstartuml", null ],
       [ "\\dotfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddotfile", null ],
       [ "\\mscfile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdmscfile", null ],
       [ "\\diafile <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmddiafile", null ],
+      [ "\\doxyconfig <config_option>", "commands.html#cmddoxyconfig", null ],
       [ "\\e <word>", "commands.html#cmde", null ],
       [ "\\em <word>", "commands.html#cmdem", null ],
       [ "\\endcode", "commands.html#cmdendcode", null ],
@@ -362,12 +396,14 @@ var NAVTREE =
       [ "\\endverbatim", "commands.html#cmdendverbatim", null ],
       [ "\\endxmlonly", "commands.html#cmdendxmlonly", null ],
       [ "\\f$", "commands.html#cmdfdollar", null ],
+      [ "\\f(", "commands.html#cmdfrndopen", null ],
+      [ "\\f)", "commands.html#cmdfrndclose", null ],
       [ "\\f[", "commands.html#cmdfbropen", null ],
       [ "\\f]", "commands.html#cmdfbrclose", null ],
       [ "\\f{environment}{", "commands.html#cmdfcurlyopen", null ],
       [ "\\f}", "commands.html#cmdfcurlyclose", null ],
       [ "\\htmlonly [\"[block]\"]", "commands.html#cmdhtmlonly", null ],
-      [ "\\image['{'option'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
+      [ "\\image['{'option[,option]'}'] <format> <file> [\"caption\"] [<sizeindication>=<size>]", "commands.html#cmdimage", null ],
       [ "\\latexonly", "commands.html#cmdlatexonly", null ],
       [ "\\manonly", "commands.html#cmdmanonly", null ],
       [ "\\li { item-description }", "commands.html#cmdli", null ],
@@ -393,7 +429,10 @@ var NAVTREE =
       [ "\\--", "commands.html#cmdndash", null ],
       [ "\\---", "commands.html#cmdmdash", null ]
     ] ],
-    [ "HTML Commands", "htmlcmds.html", null ],
+    [ "HTML Commands", "htmlcmds.html", [
+      [ "HTML tag commands", "htmlcmds.html#htmltagcmds", null ],
+      [ "HTML4 character entities", "htmlcmds.html#htmlentities", null ]
+    ] ],
     [ "XML Commands", "xmlcmds.html", null ],
     [ "Emoji support", "emojisup.html", [
       [ "Representation", "emojisup.html#emojirep", null ],
@@ -406,12 +445,19 @@ var NAVTREE =
         [ "Creation of PDF and DVI output", "perlmod.html#pm_pdf_gen", null ]
       ] ],
       [ "Documentation format.", "perlmod.html#doxydocs_format", null ],
-      [ "Data structure", "perlmod.html#doxymodel_format", null ]
+      [ "Data structure", "perlmod.html#doxymodel_format", null ],
+      [ "Perl Module Tree Nodes", "perlmod.html#perlmod_tree", null ]
     ] ],
-    [ "Perl Module Tree Nodes", "perlmod_tree.html", null ],
     [ "Doxygen's Internals", "arch.html", null ],
     [ "Changelog", "changelog.html", [
       [ "1.9 Series", "changelog.html#log_1_9", [
+        [ "Release 1.9.8", "changelog.html#log_1_9_8", null ],
+        [ "Release 1.9.7", "changelog.html#log_1_9_7", null ],
+        [ "Release 1.9.6", "changelog.html#log_1_9_6", null ],
+        [ "Release 1.9.5", "changelog.html#log_1_9_5", null ],
+        [ "Release 1.9.4", "changelog.html#log_1_9_4", null ],
+        [ "Release 1.9.3", "changelog.html#log_1_9_3", null ],
+        [ "Release 1.9.2", "changelog.html#log_1_9_2", null ],
         [ "Release 1.9.1", "changelog.html#log_1_9_1", null ],
         [ "Release 1.9.0", "changelog.html#log_1_9_0", null ]
       ] ],
@@ -456,7 +502,7 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "arch.html",
-"config.html#config_input"
+"commands.html#cmdthrows"
 ];
 
 var SYNCONMSG = 'click to disable panel synchronisation';
